@@ -47,33 +47,12 @@ class IDEArtifacts(ABC):
         pass
 
     @property
-    @abstractmethod
     def contracts(self) -> List[Contract]:
-        """ Returns sources
-        sources = {
-            "filename": [
-                {
-                    "bytecode": <>,
-                    ...
-                    "deployedBytecode": <>
-                }
-            ]
-        }
-        """
-        pass
+        return self.fetch_data()[0]
 
     @property
-    @abstractmethod
     def sources(self) -> Dict[str, Source]:
-        """ Returns sources
-        sources = {
-            "filename": {
-                "ast": <>,
-                "source: ""
-            }
-        }
-        """
-        pass
+        return self.fetch_data()[1]
 
     @staticmethod
     @abstractmethod
@@ -183,11 +162,6 @@ class IDEArtifacts(ABC):
             for k, v in _result_contracts.items()
             if self.normalize_path(k) in normalized_include
         }
-        # result_sources = {
-        #     k: v
-        #     for k, v in _result_sources.items()
-        #     if self.normalize_path(k) in normalized_include
-        # }
         return self.flatten_contracts(result_contracts), _result_sources
 
     @abstractmethod
@@ -206,3 +180,29 @@ class IDEArtifacts(ABC):
     def validate(self) -> None:
         if len(self.sources.keys()) == 0 or len(self.contracts) == 0:
             raise EmptyArtifactsError()
+
+    @staticmethod
+    def get_ignored_sources(
+        generated_sources: Optional[List[Dict[str, any]]] = None,
+        source_map: str = "",
+        source_ids: List[int] = [],
+    ) -> List[int]:
+        if generated_sources:  # compiler output has generated sources data
+            ignored_sources = set()
+            for generated_source in generated_sources:
+                if generated_source["language"].lower() == "yul" and type(
+                    generated_source["id"] is int
+                ):
+                    ignored_sources.add(generated_source["id"])
+            return sorted(list(ignored_sources))
+
+        sm = source_map.split(";")
+        all_file_ids = set()
+        for c in sm:
+            component = c.split(":")
+            if len(component) < 3 or component[2] == "":
+                continue
+            all_file_ids.add(component[2])
+        return sorted(
+            [int(file_id) for file_id in all_file_ids if int(file_id) not in source_ids]
+        )
